@@ -27,12 +27,11 @@ use InSilicoSpectro::InSilico::AASequence;
 use InSilicoSpectro::InSilico::CleavEnzyme;
 use InSilicoSpectro::Utils::io;
 
-our (@ISA, @EXPORT, @EXPORT_OK, $VERSION);
+our (@ISA, @EXPORT, @EXPORT_OK);
 @ISA = qw(Exporter);
 
-@EXPORT = qw(getVersion);
+@EXPORT = qw();
 @EXPORT_OK = ();
-$VERSION = "1.0";
 
 our %visibleAttr = (sequence=>1, modif=>1, parentProtein=>1, start=>1, end=>1, readingFrame=>1, nTerm=>1, cTerm=>1, enzymatic=>1, enzyme=>1, aaBefore=>1, aaAfter=>1, nmc=>1, addProton=>1);
 our %aaList = split(//, 'A1C1D1E1F1G1H1I1K1L1M1N1P1Q1R1S1T1V1W1Y1');
@@ -552,7 +551,7 @@ sub modifAt
     $this->{modifType} = 'MS/MS';
     undef($this->{mass});
   }
-  return $this->{modif}[$pos+1] = $modif;
+  return $this->{modif}[$pos+1];
 
 } # modifAt
 
@@ -618,7 +617,6 @@ is not set or there are variable modifications.
 sub getMass
 {
   my $this = shift;
-
   return $this->{mass} if (defined($this->{mass}) && ($this->{massType} == InSilicoSpectro::InSilico::MassCalculator::getMassType()));
 
   return undef if (!defined(my $sequence = $this->sequence()));
@@ -671,6 +669,20 @@ sub getMass
 } # getMass
 
 
+=head2 getMoZ(charge)
+
+
+=cut
+
+sub getMoZ
+{
+  my $this = shift;
+  my $charge=shift or croak "must provide a charge for Peptide->getMoZ";
+  my $m=$this->getMass();
+  $m-=InSilicoSpectro::InSilico::MassCalculator::getMass('el_H+') if ($this->addProton());
+  return $m/$charge+InSilicoSpectro::InSilico::MassCalculator::getMass('el_H+');
+}
+
 =head2 getLength
 
 Returns peptide sequence length.
@@ -714,7 +726,7 @@ sub print
 
   my $fdOut = defined($out) ? (new SelectSaver(InSilicoSpectro::Utils::io->getFD($out) || croak("cannot open [$out]: $!"))) : \*STDOUT;
   print $fdOut $this->toString(), "\n";
-  print $fdOut InSilicoSpectro::InSilico::MassCalculator::modifToString($this->modif()), "\n" if (defined($this->modif()));
+  print $fdOut "".(InSilicoSpectro::InSilico::MassCalculator::modifToString($this->modif()))."\n" if (defined($this->modif()));
   print $fdOut $this->nmc(), " missed cleavage(s)\n" if (defined($this->nmc()));
   print $fdOut "Starts at ", $this->start(), "\n" if (defined($this->start()));
   print $fdOut "Ends at ", $this->end(), "\n" if (defined($this->end()));
@@ -730,23 +742,9 @@ sub print
 }
 
 
-=head1 FUNCTIONS
-
-=head2 getVersion
-
-Object definition version.
-
-=cut
-sub getVersion
-{
-  return $VERSION;
-
-} # getVersion
-
-
 =head1 EXAMPLES
 
-See Phenyx/InSilico/test/testPeptide.pl and Phenyx/InSilico/test/testCalcDigestOOP.pl.
+See t/InSilico/testPeptide.pl and t/InSilico/testCalcDigestOOP.pl.
 
 =head1 AUTHORS
 
